"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.react = void 0;
const core_1 = require("@angular-devkit/core");
const schematics_1 = require("@angular-devkit/schematics");
function react(options) {
    return (tree, _context) => {
        const subfolder = `./${options.name}`;
        if (options.subfolder)
            tree.create(`./${options.name}`, '');
        if (tree.exists('./package.json'))
            tree.delete('./package.json');
        const pathRegexp = /__.*__/;
        const fileSource = schematics_1.url('./files');
        const notComplierEJSList = [
            'src/index.ejs'
        ];
        const shouldBeComplier = (fp) => {
            if (pathRegexp.test(fp))
                return true;
            if (fp.includes('.ejs')) {
                return !notComplierEJSList.find(f => fp.includes(f));
            }
            return false;
        };
        const parseTpl = schematics_1.apply(fileSource, [
            schematics_1.filter(shouldBeComplier),
            schematics_1.template(Object.assign(Object.assign(Object.assign({}, core_1.strings), options), { jsExt: options.ts ? 'ts' : 'js', jsxExt: options.ts ? 'tsx' : 'jsx', ifModule: (styleSheet) => options.cssModule ? `module.${styleSheet}` : styleSheet })),
            schematics_1.forEach(fileEntry => {
                try {
                    const reg = /^\s*\n/gm;
                    const content = fileEntry.content.toString().replace(reg, "");
                    tree.create(fileEntry.path.replace('.ejs', ''), content);
                    return null;
                }
                catch (e) {
                    console.log(e);
                    return fileEntry;
                }
            })
        ]);
        const exIncludes = schematics_1.apply(fileSource, [
            schematics_1.filter(fp => !fp.includes(".DS_Store") && !shouldBeComplier(fp))
        ]);
        return schematics_1.chain([
            schematics_1.mergeWith(parseTpl),
            schematics_1.mergeWith(exIncludes),
            options.useRedux ? schematics_1.noop() : schematics_1.filter(p => !p.includes('src/models') && !p.includes('src/pages/demo')),
            options.ts ? schematics_1.noop() : schematics_1.filter(p => !p.includes('tsconfig.json') && !p.includes('src/types')),
            !options.useRouter ? schematics_1.filter(p => !p.includes('src/routes.') && !p.includes('src/pages/Base.')) : schematics_1.noop(),
            options.subfolder ? schematics_1.move(subfolder) : schematics_1.noop(),
        ]);
    };
}
exports.react = react;
//# sourceMappingURL=index.js.map